@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: pixmaped-globals.pl,v 1.20 1999/08/08 15:47:20 root Exp $
+# $Id: pixmaped-globals.pl,v 1.21 1999/12/13 19:26:06 root Exp root $
 
 # Copyright (c) Mark Summerfield 1999. All Rights Reserved.
 # May be used/distributed under the GPL.
@@ -9,7 +9,6 @@ use strict ;
 
 package main ;
 
-
 $Global{WROTE_OPTS}         = 0 ;
 $Global{WROTE_IMAGE}        = 1 ;
 $Global{FILENAME_INDEX}     = 1 ;
@@ -21,6 +20,7 @@ $Global{ACTIVE_IMPLEMENT}   = 'PENCIL' ;
 $Global{ACTIVE_TOOL}        = 'pencil' ;
 $Global{COLOUR}             = 'white' ;
 $Global{BUFFER}             = 0 ;
-
+$Global{X}                  = 0 ;
+$Global{Y}                  = 0 ;
 
 1 ;
