@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: pixmaped-grid.pl,v 1.18 1999/09/04 13:25:44 root Exp $
+# $Id: pixmaped-grid.pl,v 1.19 1999/12/13 19:26:06 root Exp root $
 
 # Copyright (c) Mark Summerfield 1999. All Rights Reserved.
 # May be used/distributed under the GPL.
@@ -9,7 +9,6 @@ use strict ;
 
 package main ;
 
-
 my $StatusFrame = $Win->Frame()->pack( 
                 -side   => 'bottom', 
                 -expand => 1, 
@@ -56,14 +55,12 @@ $Grid{STATUS} = $StatusFrame->Label(
                         -pady   => 3,
                         ) ;
 
-
 my $CanvasFrame = $Win->Frame()->pack(
                 -side   => 'top',
                 -expand => 1,
                 -fill   => 'both',
                 ) ;
 
-
 $Grid{XSCROLL} = $CanvasFrame->Scrollbar( -orient => 'horizontal' ) ;
 $Grid{YSCROLL} = $CanvasFrame->Scrollbar() ;
 
@@ -92,7 +89,7 @@ $Grid{CANVAS}->Tk::bind( '<B1-Motion>', [ \&grid::motion1,  Ev( 'x' ), Ev( 'y' )
 $Grid{CANVAS}->Tk::bind( '<2>',         [ \&grid::click2,   Ev( 'x' ), Ev( 'y' ) ] ) ;
 $Grid{CANVAS}->Tk::bind( '<3>',         [ \&grid::click3,   Ev( 'x' ), Ev( 'y' ) ] ) ;
 $Grid{CANVAS}->Tk::bind( '<Leave>',     [ \&grid::leave,    Ev( 'x' ), Ev( 'y' ) ] ) ;
-$Grid{CANVAS}->Tk::bind( '<Enter>',     [ \&grid::enter,    Ev( 'x' ), Ev( 'y' ) ] ) ;
- 
+$Grid{CANVAS}->Tk::bind( '<Motion>',    [ \&grid::motion,   Ev( 'x' ), Ev( 'y' ) ] ) ; 
+
 
 1 ;
